/********************************************************************************************************
 *  2005 of V Rama Aravind. ramavorray@ieee.org, www.funnotes.net, University of Oxford, Oxford, UK.
 *  This file comes with no warranty or liability. If you use this code, you should understand that
 *  you are using it at your own risk. I am not responsible for any type of loss, damage or
 *  mutiliation to the data or property of any type and variety, that might result with this code.
 *
 *  You can freely copy, distribute and modify all or part of this code maintained that this
 *  copyright message is kept in tact without any alterations. This whole copytight message has
 *  to be kept in unedited form in each and every copy of this file and its contents. This message
 *  should not be altered in any form through any means. This does not indicate that I have responsibility
 *  on this code when you use it, in whatever application it may be.
 *******************************************************************************************************/

#ifndef __COLOUR_
#define __COLOUR_

#include "stdafx.h"
#include <GL/gl.h>
#include <GL/glu.h>

/**
 * Colour.h - Used for specifying OpenGL colours intuitively.
 * All colours have been coded with their RGB values which are
 * well user understandable and they will be converted into 
 * OpenGL colour specification in the range 0 to 1 when a function
 * is called.
 *
 * Usage: glColor3dv(Colour::Instance()->{colour name});
 * eg.: glColor3dv(Colour::Instance()->white());
 * 
 * Instantiated as Single-Ton object.
 * 
 * Colour names obtained from http://www.help4web.net/webmaster/Color/RGB-Values.html and http://www.oreilly.com/catalog/wdnut/excerpt/color_names.html O'Reilly & Associates, Inc.
 * accessed 8 june 04 and 30 june 04 , respectively.
 */

class Colour
{
public:
	/**
	 * static instance creator. Should be called once to instantiate the global instance of the object.
	 * @param none
	 * @return static instance of the object
	 */
	static Colour* Initialize(void);
	
	/**
	 * method for accessing static instance of the object and thereby member functions of the class. The function 'Initialize' will also do the same thing. But there should be a distinction between our nomenclature for initializing and accessing. Also the functionality that returns the static instance of the object when called 'Initialize' will act as a guard if this function is accidentally called more than once. Without this guard multiple initializations would become a serious problem.
	 * @see Initialize()
	 * @param none
	 * @return static instance of the object from which you can call member functions
	 */
	static Colour* Instance(void);
	
	/**
	 * Static function to destroy the static instance of the object. Must be called Once, and only once, in an application, preferably at the point where your application performs clean up operations and exits.
	 * @param none
	 * @return none
	 */
	static void Destroy(void);

private:
	/**
	 * A static variable to hold the object's instance globally
	 */
	static Colour *_instance;

public:

	/**
	 * Default Constructor
	 * @param none
	 */
	Colour(void);
	
	/**
	 * Constructor
	 * @param Three Byte values R,G and B. Alpha is set to 255 (1.0)
	 */
	Colour(GLubyte R, GLubyte G, GLubyte B);
	
	/**
	 * Constructor
	 * @param A double array of four values indicating and RGB and A.
	 */
	Colour(double *colours);
	
	/**
	 * Class's destructor
	 */
	~Colour(void);

	/**
	 * Function for returning colour white
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* White(void);

	/**
	 * Function for returning colour black
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Black(void);

	/**
	 * Function for returning colour red
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Red(void);

	/**
	 * Function for returning colour green
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Green(void);

	/**
	 * Function for returning colour blue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Blue(void);

	/**
	 * Function for returning colour yellow
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Yellow(void);

	/**
	 * Function for returning colour cyan
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Cyan(void);

	/**
	 * Function for returning colour magenta
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Magenta(void);

	/**
	 * Function for returning colour violet
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Violet(void);

	/**
	 * Function for returning colour indigo
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Indigo(void);

	/**
	 * Function for returning colour orange
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Orange(void);

	/**
	 * Function for returning colour gray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Gray(void);

	/**
	 * Function for returning colour brown
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Brown(void);

	/**
	 * Function for returning colour gold
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Gold(void);
	
	/**
	 * Function for returning colour snow
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */	
	double* Snow(void);

	/**
	 * Function for returning colour ghostwhite
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Ghostwhite(void);

	/**
	 * Function for returning colour whitesmoke
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* WhiteSmoke(void);

	/**
	 * Function for returning colour gainsboro
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Gainsboro(void);

	/**
	 * Function for returning colour floralwhite
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* FloralWhite(void);

	/**
	 * Function for returning colour oldlace
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* OldLace(void);

	/**
	 * Function for returning colour linen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Linen(void);

	/**
	 * Function for returning colour antiquewhite
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* AntiqueWhite(void);

	/**
	 * Function for returning colour papayawhip
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PapayaWhip(void);

	/**
	 * Function for returning colour blanchedalmond
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* BlanchedAlmond(void);

	/**
	 * Function for returning colour bisque
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Bisque(void);

	/**
	 * Function for returning colour peachpuff
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PeachPuff(void);

	/**
	 * Function for returning colour navajowhite
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* NavajoWhite(void);

	/**
	 * Function for returning colour moccasin
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Moccasin(void);

	/**
	 * Function for returning colour cornsilk
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* CornSilk(void);

	/**
	 * Function for returning colour ivory
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Ivory(void);

	/**
	 * Function for returning colour lemonchiffon
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LemonChiffon(void);

	/**
	 * Function for returning colour seashell
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SeaShell(void);

	/**
	 * Function for returning colour honeydew
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* HoneyDew(void);

	/**
	 * Function for returning colour mintcream
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MintCream(void);

	/**
	 * Function for returning colour azure
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Azure(void);

	/**
	 * Function for returning colour aliceblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* AliceBlue(void);

	/**
	 * Function for returning colour lavender
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Lavender(void);

	/**
	 * Function for returning colour lavenderblush
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LavenderBlush(void);

	/**
	 * Function for returning colour mistyrose
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MistyRose(void);

	/**
	 * Function for returning colour darkslategray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkSlateGray(void);

	/**
	 * Function for returning colour dimgray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DimGray(void);

	/**
	 * Function for returning colour slategray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SlateGray(void);

	/**
	 * Function for returning colour lighslatetgray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightSlateGray(void);

	/**
	 * Function for returning colour lightgrey
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightGrey(void);

	/**
	 * Function for returning colour midnightblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MidnightBlue(void);

	/**
	 * Function for returning colour navyblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* NavyBlue(void);

	/**
	 * Function for returning colour cornflowerblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* CornFlowerBlue(void);

	/**
	 * Function for returning colour darkslateblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkSlateBlue(void);

	/**
	 * Function for returning colour slateblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SlateBlue(void);

	/**
	 * Function for returning colour mediumslateblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MediumSlateBlue(void);

	/**
	 * Function for returning colour royalblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* RoyalBlue(void);

	/**
	 * Function for returning colour dodgerblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DodgerBlue(void);

	/**
	 * Function for returning colour deepskyblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DeepSkyBlue(void);

	/**
	 * Function for returning colour skyblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SkyBlue(void);

	/**
	 * Function for returning colour lightskyblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightSkyBlue(void);

	/**
	 * Function for returning colour steelblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SteelBlue(void);

	/**
	 * Function for returning colour lightblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightBlue(void);

	/**
	 * Function for returning colour powderblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PowderBlue(void);

	/**
	 * Function for returning colour paleturquoise
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PaleTurquoise(void);

	/**
	 * Function for returning colour darkturquoise
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkTurquoise(void);

	/**
	 * Function for returning colour turquoise
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Turquoise(void);

	/**
	 * Function for returning colour cadetblue
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* CadetBlue(void);

	/**
	 * Function for returning colour mediumaquamarine
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MediumAquamarine(void);

	/**
	 * Function for returning colour darkolivegreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkOliveGreen(void);

	/**
	 * Function for returning colour darkseagreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkSeaGreen(void);

	/**
	 * Function for returning colour seagreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SeaGreen(void);

	/**
	 * Function for returning colour palegreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PaleGreen(void);

	/**
	 * Function for returning colour springgreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SpringGreen(void);

	/**
	 * Function for returning colour lawngreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LawnGreen(void);

	/**
	 * Function for returning colour chartreuse
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* ChartReUse(void);

	/**
	 * Function for returning colour greenyellow
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* GreenYellow(void);

	/**
	 * Function for returning colour forestgreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* ForestGreen(void);

	/**
	 * Function for returning colour darkkhaki
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkKhaki(void);

	/**
	 * Function for returning colour khaki
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Khaki(void);

	/**
	 * Function for returning colour rosybrown
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* RosyBrown(void);

	/**
	 * Function for returning colour indianred
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* IndianRed(void);

	/**
	 * Function for returning colour saddlebrown
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SaddleBrown(void);

	/**
	 * Function for returning colour sienna
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Sienna(void);

	/**
	 * Function for returning colour peru
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Peru(void);

	/**
	 * Function for returning colour burlywood
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* BurlyWood(void);

	/**
	 * Function for returning colour beige
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Beige(void);

	/**
	 * Function for returning colour wheat
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Wheat(void);

	/**
	 * Function for returning colour sandybrown
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* SandyBrown(void);

	/**
	 * Function for returning colour tan
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Tan(void);

	/**
	 * Function for returning colour chocolate
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Chocolate(void);

	/**
	 * Function for returning colour firebrick
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* FireBrick(void);

	/**
	 * Function for returning colour darksalmon
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkSalmon(void);

	/**
	 * Function for returning colour salmon
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Salmon(void);

	/**
	 * Function for returning colour darkorange
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkOrange(void);

	/**
	 * Function for returning colour coral
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Coral(void);

	/**
	 * Function for returning colour lightcoral
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightCoral(void);

	/**
	 * Function for returning colour tomato
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Tomato(void);

	/**
	 * Function for returning colour orangered
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* OrangeRed(void);

	/**
	 * Function for returning colour hotpink
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* HotPink(void);

	/**
	 * Function for returning colour deeppink
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DeepPink(void);

	/**
	 * Function for returning colour pink
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Pink(void);

	/**
	 * Function for returning colour palevioletred
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* PaleVioletRed(void);

	/**
	 * Function for returning colour maroon
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Maroon(void);

	/**
	 * Function for returning colour mediumvioletred
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* MediumVioletRed(void);

	/**
	 * Function for returning colour plum
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Plum(void);

	/**
	 * Function for returning colour orchid
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Orchid(void);

	/**
	 * Function for returning colour blueviolet
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* BlueViolet(void);

	/**
	 * Function for returning colour purple
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* Purple(void);

	/**
	 * Function for returning colour darkgray
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkGray(void);

	/**
	 * Function for returning colour darkcyan
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkCyan(void);

	/**
	 * Function for returning colour darkmagenta
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkMagenta(void);

	/**
	 * Function for returning colour darkred
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* DarkRed(void);

	/**
	 * Function for returning colour lightgreen
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* LightGreen(void);

	/**
	 * Function for returning current colour that is set in the class (in other words, previously accessed colour from the global instance of the object)
	 * @param none
	 * @return A double array of four values (RGBA) - By default Alpha (A) is set to 1 (total opaque)
	 */
	double* CurrColour(void);

	/**
	 * method to set alpha value. should be in the range 0 and 1
	 * @param A float value ranging between 0 and 1 indicating transparency. This value sets the transparency valu of the class to that value. Subsequent calls to colour function uses this value to return the Alpha value.
	 * @return none
	 */
	void Alpha(float A);

	/**
	 * Get an OpenGL equivalent value (in the range 0 to 1) for Byte-Wise RGBA values
	 * @param Four GLubyte values indicating RGB and A. A (Alpha) is an optional value and by default it is set to the value - 255.
	 * @return A double array of four values with values in the range 0 to 1 in each
	 */
	inline double* GetColour(GLubyte R, GLubyte G, GLubyte B, GLubyte A=255);
	//double* GetColour(unsigned short R, unsigned short G, unsigned short B, unsigned short A=65535);
	
	/**
	 * overloaded '=' operator to copy values of one object to another. not suitable when using this class as single-ton object
	 * @param An instance of the Colour object
	 * @return Reference of the object from which it is called
	 */
	const Colour& operator =(const Colour &);

	/**
	 * overloaded '=' operator to copy values of one object to another. not suitable when using this class as single-ton object
	 * @param A double array of four values
	 * @return Reference of the object from which it is called
	 */
	const Colour& operator =(const double *);
	
	
protected:
	/**
	 * converts RGBA values (BYTES) to OpenGL variants in the range 0 and 1. Used only internally. Not meant for public access.
	 * @param none
	 * @return A double array of four values
	 */
	double* RGBToOpenGLColours();
	
	/**
	 * converts RGBA values (UNSIGNED SHORTS) to OpenGL variants in the range 0 and 1. Used only internally. Not meant for public access.
	 * @param none
	 * @return A double array of four values
	 */
	double* RGBToOpenGLColoursUS();

private:
	/**
	 * A Byte array to store RGBA values
	 */
	GLubyte _RGBAColours[4];

	/**
	 * An Unsigned Short array to store RGBA values
	 */
	unsigned short _ushortRGBAColours[4];
	
	/**
	 * A double array to store OpenGL colour values
	 */
	double _colours[4];
};

inline double* Colour::GetColour(GLubyte R, GLubyte G, GLubyte B, GLubyte A)
{
	_RGBAColours[0]=R;
	_RGBAColours[1]=G;
	_RGBAColours[2]=B;
	_RGBAColours[3]=A;
	return RGBToOpenGLColours();
}

#endif //__COLOUR_
